<template>
    <div>
        <Head title="Role"/>
        <v-card dense>
            <v-data-table :headers="headers" :items="roles" class="elevation-1">
                <template v-slot:top>

                    <v-dialog v-model="dialogEdit" max-width="500px">
                        <v-card>
                            <v-toolbar color="primary" dark>Edit Role</v-toolbar>
                            <v-card-text>
                                <v-container>
                                    <v-row>
                                        <v-col cols="12" >
                                            <v-text-field v-model="editedItem.name" label="Name" :rules="rules" :error-messages="error  && !editedItem.name ? ['This field is required.'] : ''"></v-text-field>
                                        </v-col>
                                        <v-col cols="12">
                                            <v-textarea v-model="editedItem.description" rows="2" label="Description" :rules="rules" :error-messages="error  && !editedItem.description ? ['This field is required.'] : ''"></v-textarea>
                                        </v-col>
                                    </v-row>
                                </v-container>
                            </v-card-text>
                            <v-card-actions>
                                <v-btn small color="primary" text @click="close"> Cancel</v-btn>
                                <v-spacer></v-spacer>
                                <v-btn small color="primary" text @click="save">Save</v-btn>
                            </v-card-actions>
                        </v-card>
                    </v-dialog>

                </template>
                <template v-slot:item.actions="{ item }">
                    <v-menu bottom left dense offset-y>
                        <template v-slot:activator="{ on, attrs }">
                            <v-btn small icon v-bind="attrs" v-on="on">
                                <v-icon>mdi-dots-vertical</v-icon>
                            </v-btn>
                        </template>
                        <v-list dense class="py-0">
                            <v-list-item @click="editItem(item)" link>
                                <v-list-item-title>
                                    <v-icon small>mdi-pencil</v-icon>
                                    Edit Role
                                </v-list-item-title>
                            </v-list-item>
                            <v-divider/>
                            <v-list-item @click="deleteItem(item)" link class="error--text">
                                <v-list-item-title>
                                    <v-icon small color="error">mdi-delete</v-icon>
                                    Delete Role
                                </v-list-item-title>
                            </v-list-item>
                        </v-list>
                    </v-menu>
                </template>
            </v-data-table>
        </v-card>
    </div>
</template>

<script>
import Role from "./Role.vue";
import Settings from "../../../Components/Layouts/Settings.vue";
import Setting from "../Setting.vue";

export default {
    name: "RoleIndex",
    layout: [Settings, Setting, Role],
    data: () => ({
        error: false,
        rules: [
            value => !!value || 'Please fill this field.'
        ],
        dialogEdit: false,
        headers: [
            {text: 'Name', align: 'start', value: 'name'},
            {text: 'Description', value: 'description'},
            {text: 'Action', value: 'actions', sortable: false},
        ],
        roles: [],
        editedIndex: -1,
        editedItem: {
            name: '',
            description: ''
        },
        defaultItem: {
            name: '',
            description: ''
        },
    }),

    computed: {
        formTitle() {
            return this.editedIndex === -1 ? 'Updated role' : 'Edited role'
        },
    },

    watch: {
        dialog(val) {
            val || this.close()
        },
        dialogDelete(val) {
            val || this.closeDelete()
        },
    },

    created() {
        this.initialize()
    },

    methods: {
        initialize() {
            this.roles = this.$page.props.roles
        },

        editItem(item) {
            this.editedIndex = this.roles.indexOf(item)
            this.editedItem = Object.assign({}, item)
            this.dialogEdit = true
        },

        deleteItem(item) {
            this._confirmDialog({
                message: 'Are you sure you want to delete this role?',
                showCancel: true,
                confirm: () => {
                    this.editedIndex = this.roles.indexOf(item)
                    this.editedItem = Object.assign({}, item)
                    this.roles.splice(this.editedIndex, 1)
                    this.closeDelete()
                    this.$inertia.delete(this.$route('role.delete', this.editedItem.id), {
                        onBefore: () => {
                        },
                        onSuccess: (page) => {
                            this.showSnack(["Successfully deleted role!"]);
                        },
                        onError: (errors) => {
                            console.log(errors)
                            this.showSnack(["Role not deleted!", "error"]);
                        },
                        onFinish: visit => {
                        },
                    });
                }
            })
        },

        close() {
            this.dialogEdit = false
            this.$nextTick(() => {
                this.editedItem = Object.assign({}, this.defaultItem)
                this.editedIndex = -1
            })
        },

        closeDelete() {
            this.$nextTick(() => {
                this.editedItem = Object.assign({}, this.defaultItem)
                this.editedIndex = -1
            })
        },

        save() {
            if (this.editedIndex > -1) {
                if (this.editedItem.name!='' && this.editedItem.description!='') {
                    Object.assign(this.roles[this.editedIndex], this.editedItem)
                    this.$inertia.put(this.$route('role.edit', this.roles[this.editedIndex].id), this.roles[this.editedIndex], {
                        onBefore: () => {
                        },
                        onSuccess: (page) => {
                            this.showSnack(["Successfully updated role!"])
                        },
                        onError: (errors) => {
                            console.log(errors)
                            this.error = true
                            this.showSnack(["Role not updated!", "error"])
                        },
                        onFinish: visit => {
                        },
                    });
                    this.close()
                } else {
                    this.error = true
                    this.showSnack(["Role not updated!", "error"])
                }

            }
        },
    },
}
</script>

<style scoped>

</style>
